@@ -47,7 +47,9 @@ gofPIOSRn <- function(copula = c("normal", "t", "clayton", "gumbel", "frank"), x
   }
   if (!is.null(seed.active) & length(seed.active) == 1) {
     set.seed(seed.active)
+    RNGsetting <- RNGkind()
     RNGkind(sample.kind = "default")
+    on.exit(RNGkind(sample.kind = RNGsetting[3]))
     seed.active <- sample(x = 2147483647, size = M + 1)
   }
   if (!is.null(seed.active) & all(!vapply(seed.active, function(x) x %% 1 == 0, TRUE))) {
@@ -123,7 +125,9 @@ gofPIOSTn <- function(copula = c("normal", "t", "clayton", "gumbel", "frank"), x
   }
   if (!is.null(seed.active) & length(seed.active) == 1) {
     set.seed(seed.active)
+    RNGsetting <- RNGkind()
     RNGkind(sample.kind = "default")
+    on.exit(RNGkind(sample.kind = RNGsetting[3]))
     seed.active <- sample(x = 2147483647, size = M + 1)
   }
   if (!is.null(seed.active) & all(!vapply(seed.active, function(x) x %% 1 == 0, TRUE))) {
@@ -214,7 +218,9 @@ gofKernel <- function(copula = c("normal", "t", "clayton", "gumbel", "frank"), x
   }
   if (!is.null(seed.active) & length(seed.active) == 1) {
     set.seed(seed.active)
+    RNGsetting <- RNGkind()
     RNGkind(sample.kind = "default")
+    on.exit(RNGkind(sample.kind = RNGsetting[3]))
     seed.active <- sample(x = 2147483647, size = M + 1)
   }
   if (!is.null(seed.active) & all(!vapply(seed.active, function(x) x %% 1 == 0, TRUE))) {
