@@ -78,7 +78,9 @@ gof <- function(x, priority = "tests", copula = NULL, tests = NULL, customTests
   }
   if (!is.null(seed.active) & length(seed.active) == 1) {
     set.seed(seed.active)
+    RNGsetting <- RNGkind()
     RNGkind(sample.kind = "default")
+    on.exit(RNGkind(sample.kind = RNGsetting[3]))
     seed.active <- sample(x = 2147483647, size = M + 1)
   }
   if (!is.null(seed.active) & all(!vapply(seed.active, function(x) x %% 1 == 0, TRUE))) {
